========================
 Invenio-Records v0.2.1
========================

Invenio-Records v0.2.1 was released on August 12, 2015.

About
-----

Invenio-Records is a metadata storage module.

*This is an experimental development preview release.*

Bug fixes
---------

- Adapts tests for non-repeatable subfields fixed in DoJSON==0.1.1.
- Adds missing dependencies "JSONSchema" and  "invenio-formatter".

Installation
------------

   $ pip install invenio-records==0.2.1

Documentation
-------------

   http://invenio-records.readthedocs.org/en/v0.2.1

Happy hacking and thanks for flying Invenio-Records.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-records
|   URL: http://invenio-software.org
